@@ -39,10 +39,9 @@ DeviceDbusInterface::DeviceDbusInterface(const QString &id, QObject *parent)
                                       parent)
     , m_id(id)
 {
-    connect(this, &OrgKdeKdeconnectDeviceInterface::trustedChanged, this, &DeviceDbusInterface::trustedChangedProxy);
+    connect(this, &OrgKdeKdeconnectDeviceInterface::pairStateChanged, this, &DeviceDbusInterface::pairStateChangedProxy);
     connect(this, &OrgKdeKdeconnectDeviceInterface::reachableChanged, this, &DeviceDbusInterface::reachableChangedProxy);
     connect(this, &OrgKdeKdeconnectDeviceInterface::nameChanged, this, &DeviceDbusInterface::nameChangedProxy);
-    connect(this, &OrgKdeKdeconnectDeviceInterface::hasPairingRequestsChanged, this, &DeviceDbusInterface::hasPairingRequestsChangedProxy);
 }
 
 DeviceDbusInterface::~DeviceDbusInterface()
@@ -227,15 +226,21 @@ ShareDbusInterface::ShareDbusInterface(const QString &deviceId, QObject *parent)
 
 ShareDbusInterface::~ShareDbusInterface() = default;
 
-PhotoDbusInterface::PhotoDbusInterface(const QString& deviceId, QObject* parent):
-    OrgKdeKdeconnectDevicePhotoInterface(DaemonDbusInterface::activatedService(), QStringLiteral("/modules/kdeconnect/devices/")  + deviceId + QStringLiteral("/photo"), QDBusConnection::sessionBus(), parent)
+PhotoDbusInterface::PhotoDbusInterface(const QString &deviceId, QObject *parent)
+    : OrgKdeKdeconnectDevicePhotoInterface(DaemonDbusInterface::activatedService(),
+                                           QStringLiteral("/modules/kdeconnect/devices/") + deviceId + QStringLiteral("/photo"),
+                                           QDBusConnection::sessionBus(),
+                                           parent)
 {
 }
 
 PhotoDbusInterface::~PhotoDbusInterface() = default;
 
-RemoteSystemVolumeDbusInterface::RemoteSystemVolumeDbusInterface(const QString& deviceId, QObject* parent):
-    OrgKdeKdeconnectDeviceRemotesystemvolumeInterface(DaemonDbusInterface::activatedService(), QStringLiteral("/modules/kdeconnect/devices/")  + deviceId + QStringLiteral("/remotesystemvolume"), QDBusConnection::sessionBus(), parent)
+RemoteSystemVolumeDbusInterface::RemoteSystemVolumeDbusInterface(const QString &deviceId, QObject *parent)
+    : OrgKdeKdeconnectDeviceRemotesystemvolumeInterface(DaemonDbusInterface::activatedService(),
+                                                        QStringLiteral("/modules/kdeconnect/devices/") + deviceId + QStringLiteral("/remotesystemvolume"),
+                                                        QDBusConnection::sessionBus(),
+                                                        parent)
 {
 }
 
@@ -262,3 +267,17 @@ VirtualmonitorDbusInterface::VirtualmonitorDbusInterface(const QString &deviceId
 VirtualmonitorDbusInterface::~VirtualmonitorDbusInterface()
 {
 }
+
+#include <iostream>
+ClipboardDbusInterface::ClipboardDbusInterface(const QString &deviceId, QObject *parent)
+    : OrgKdeKdeconnectDeviceClipboardInterface(DaemonDbusInterface::activatedService(),
+                                               QStringLiteral("/modules/kdeconnect/devices/") + deviceId + QStringLiteral("/clipboard"),
+                                               QDBusConnection::sessionBus(),
+                                               parent)
+{
+    connect(this, &OrgKdeKdeconnectDeviceClipboardInterface::autoShareDisabledChanged, this, &ClipboardDbusInterface::autoShareDisabledChangedProxy);
+}
+
+ClipboardDbusInterface::~ClipboardDbusInterface()
+{
+}
