@@ -1,21 +1,7 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "mprisremoteplugin.h"
@@ -30,8 +16,7 @@
 
 K_PLUGIN_CLASS_WITH_JSON(MprisRemotePlugin, "kdeconnect_mprisremote.json")
 
-
-MprisRemotePlugin::MprisRemotePlugin(QObject* parent, const QVariantList& args)
+MprisRemotePlugin::MprisRemotePlugin(QObject *parent, const QVariantList &args)
     : KdeConnectPlugin(parent, args)
     , m_currentPlayer()
     , m_players()
@@ -42,15 +27,15 @@ MprisRemotePlugin::~MprisRemotePlugin()
 {
 }
 
-bool MprisRemotePlugin::receivePacket(const NetworkPacket& np)
+bool MprisRemotePlugin::receivePacket(const NetworkPacket &np)
 {
     if (np.type() != PACKET_TYPE_MPRIS)
         return false;
 
     if (np.has(QStringLiteral("player"))) {
         const QString player = np.get<QString>(QStringLiteral("player"));
-        if(!m_players.contains(player)) {
-             m_players[player] = new MprisRemotePlayer(player, this);
+        if (!m_players.contains(player)) {
+            m_players[player] = new MprisRemotePlayer(player, this);
         }
         m_players[player]->parseNetworkPacket(np);
     }
@@ -58,7 +43,7 @@ bool MprisRemotePlugin::receivePacket(const NetworkPacket& np)
     if (np.has(QStringLiteral("playerList"))) {
         QStringList players = np.get<QStringList>(QStringLiteral("playerList"));
 
-        //Remove players not available any more
+        // Remove players not available any more
         for (auto iter = m_players.begin(); iter != m_players.end();) {
             if (!players.contains(iter.key())) {
                 iter.value()->deleteLater();
@@ -68,8 +53,8 @@ bool MprisRemotePlugin::receivePacket(const NetworkPacket& np)
             }
         }
 
-        //Add new players
-        for (const QString& player : players) {
+        // Add new players
+        for (const QString &player : players) {
             if (!m_players.contains(player)) {
                 m_players[player] = new MprisRemotePlayer(player, this);
                 requestPlayerStatus(player);
@@ -81,7 +66,6 @@ bool MprisRemotePlugin::receivePacket(const NetworkPacket& np)
         } else if (!m_players.contains(m_currentPlayer)) {
             m_currentPlayer = m_players.firstKey();
         }
-
     }
     Q_EMIT propertiesChanged();
 
@@ -99,13 +83,10 @@ QString MprisRemotePlugin::dbusPath() const
     return QStringLiteral("/modules/kdeconnect/devices/") + device()->id() + QStringLiteral("/mprisremote");
 }
 
-void MprisRemotePlugin::requestPlayerStatus(const QString& player)
+void MprisRemotePlugin::requestPlayerStatus(const QString &player)
 {
-    NetworkPacket np(PACKET_TYPE_MPRIS_REQUEST, {
-        {QStringLiteral("player"), player},
-        {QStringLiteral("requestNowPlaying"), true},
-        {QStringLiteral("requestVolume"), true}}
-    );
+    NetworkPacket np(PACKET_TYPE_MPRIS_REQUEST,
+                     {{QStringLiteral("player"), player}, {QStringLiteral("requestNowPlaying"), true}, {QStringLiteral("requestVolume"), true}});
     sendPacket(np);
 }
 
@@ -115,44 +96,33 @@ void MprisRemotePlugin::requestPlayerList()
     sendPacket(np);
 }
 
-void MprisRemotePlugin::sendAction(const QString& action)
+void MprisRemotePlugin::sendAction(const QString &action)
 {
-    NetworkPacket np(PACKET_TYPE_MPRIS_REQUEST, {
-        {QStringLiteral("player"), m_currentPlayer},
-        {QStringLiteral("action"), action}
-    });
+    NetworkPacket np(PACKET_TYPE_MPRIS_REQUEST, {{QStringLiteral("player"), m_currentPlayer}, {QStringLiteral("action"), action}});
     sendPacket(np);
 }
 
 void MprisRemotePlugin::seek(int offset) const
 {
-    NetworkPacket np(PACKET_TYPE_MPRIS_REQUEST, {
-        {QStringLiteral("player"), m_currentPlayer},
-        {QStringLiteral("Seek"), offset}});
+    NetworkPacket np(PACKET_TYPE_MPRIS_REQUEST, {{QStringLiteral("player"), m_currentPlayer}, {QStringLiteral("Seek"), offset}});
     sendPacket(np);
 }
 
 void MprisRemotePlugin::setVolume(int volume)
 {
-    NetworkPacket np(PACKET_TYPE_MPRIS_REQUEST, {
-        {QStringLiteral("player"), m_currentPlayer},
-        {QStringLiteral("setVolume"), volume}
-    });
+    NetworkPacket np(PACKET_TYPE_MPRIS_REQUEST, {{QStringLiteral("player"), m_currentPlayer}, {QStringLiteral("setVolume"), volume}});
     sendPacket(np);
 }
 
 void MprisRemotePlugin::setPosition(int position)
 {
-    NetworkPacket np(PACKET_TYPE_MPRIS_REQUEST, {
-        {QStringLiteral("player"), m_currentPlayer},
-        {QStringLiteral("SetPosition"), position}
-    });
+    NetworkPacket np(PACKET_TYPE_MPRIS_REQUEST, {{QStringLiteral("player"), m_currentPlayer}, {QStringLiteral("SetPosition"), position}});
     sendPacket(np);
 
     m_players[m_currentPlayer]->setPosition(position);
 }
 
-void MprisRemotePlugin::setPlayer(const QString& player)
+void MprisRemotePlugin::setPlayer(const QString &player)
 {
     if (m_currentPlayer != player) {
         m_currentPlayer = player;
@@ -191,12 +161,6 @@ QStringList MprisRemotePlugin::playerList() const
     return m_players.keys();
 }
 
-QString MprisRemotePlugin::nowPlaying() const
-{
-    auto player = m_players.value(m_currentPlayer);
-    return player ? player->nowPlaying() : QString();
-}
-
 QString MprisRemotePlugin::title() const
 {
     auto player = m_players.value(m_currentPlayer);
